@@ -1,7 +1,7 @@
 /*
  * segatex SELinux tool.
  *
- * Copyright (C) 2007-2010 Shintaro Fujiwara 
+ * Copyright (C) 2007-2012 Shintaro Fujiwara 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -46,30 +46,30 @@ Downloader::Downloader(QWidget *parent, const char *name): QDialog(parent, name)
 	setCaption(tr("Download fedora"));
 
         optionButtonGroup = new Q3ButtonGroup(this);
-        optionButtonGroup->resize( 350, 50 );
+        optionButtonGroup->resize( 400, 50 );
         usRadioButton = new QRadioButton(tr("us ftp site (mirrors.kernel.org)"), optionButtonGroup);
-        usRadioButton->setGeometry( 10, 10, 300, 20 );
+        usRadioButton->setGeometry( 10, 10, 320, 20 );
         jpRadioButton = new QRadioButton(tr("jp ftp site (ftp.riken.jp)"), optionButtonGroup);
-        jpRadioButton->setGeometry( 10, 30, 300, 20 );
+        jpRadioButton->setGeometry( 10, 30, 320, 20 );
+        deRadioButton = new QRadioButton(tr("german ftp site (ftp.uni-kl.de)"), optionButtonGroup);
+        deRadioButton->setGeometry( 10, 50, 320, 20 );
+        frRadioButton = new QRadioButton(tr("french ftp site (ftp.lip6.fr)"), optionButtonGroup);
+        frRadioButton->setGeometry( 10, 70, 320, 20 );
+        auRadioButton = new QRadioButton(tr("Australian ftp site (mirror.aarnet.edu.au)"), optionButtonGroup);
+        auRadioButton->setGeometry( 10, 90, 320, 20 );
 	usRadioButton->setChecked(true);
 
         fedoraVersionButtonGroup = new Q3ButtonGroup(this);
         fedoraVersionButtonGroup->resize( 150, 70 );
-	/*
-        sevenRadioButton = new QRadioButton(tr("version 7"), fedoraVersionButtonGroup);
-        sevenRadioButton->setGeometry( 10, 10, 300, 20 );
-        eightRadioButton = new QRadioButton(tr("version 8"), fedoraVersionButtonGroup);
-        eightRadioButton->setGeometry( 10, 10, 300, 20 );
-	*/
-        nineRadioButton = new QRadioButton(tr("version 9"), fedoraVersionButtonGroup);
-        nineRadioButton->setGeometry( 10, 10, 300, 20 );
-        tenRadioButton = new QRadioButton(tr("version 10"), fedoraVersionButtonGroup);
-        tenRadioButton->setGeometry( 10, 30, 300, 20 );
-        elevenRadioButton = new QRadioButton(tr("version 11"), fedoraVersionButtonGroup);
-        elevenRadioButton->setGeometry( 10, 50, 300, 20 );
-        twelveRadioButton = new QRadioButton(tr("version 12"), fedoraVersionButtonGroup);
-        twelveRadioButton->setGeometry( 10, 70, 300, 20 );
-	twelveRadioButton->setChecked(true);
+        thirteenRadioButton = new QRadioButton(tr("version 13"), fedoraVersionButtonGroup);
+        thirteenRadioButton->setGeometry( 10, 10, 300, 20 );
+        fourteenRadioButton = new QRadioButton(tr("version 14"), fedoraVersionButtonGroup);
+        fourteenRadioButton->setGeometry( 10, 30, 300, 20 );
+        fifteenRadioButton = new QRadioButton(tr("version 15"), fedoraVersionButtonGroup);
+        fifteenRadioButton->setGeometry( 10, 50, 300, 20 );
+        sixteenRadioButton = new QRadioButton(tr("version 16"), fedoraVersionButtonGroup);
+       	sixteenRadioButton->setGeometry( 10, 70, 300, 20 );
+	sixteenRadioButton->setChecked(true);
 
 	downloadButton = new QPushButton(tr("Download Fedora"), this);
 	downloadButton->setPaletteBackgroundColor(QColor(100,200,200));
@@ -114,7 +114,7 @@ Downloader::Downloader(QWidget *parent, const char *name): QDialog(parent, name)
 	mainLayout->addLayout(middleLayout);
 	//mainLayout->addLayout(firstLayout);
 	mainLayout->addLayout(footLayout);
-	resize(630,250);
+	resize(660,250);
 }
 
 void Downloader::download_button_clicked()
@@ -124,50 +124,85 @@ void Downloader::download_button_clicked()
 		Q3Url url_for_fedora("ftp://mirrors.usc.edu");
 		url_for_fedora.setPort(21);
 		mirror = 1;
-		/*
-		if(sevenRadioButton->isChecked()){
-			version = "seven";
+		if(thirteenRadioButton->isChecked()){
+			version = "thirteen";
 		}
-		if(eightRadioButton->isChecked()){
-			version = "eight";
+		if(fourteenRadioButton->isChecked()){
+			version = "fourteen";
 		}
-		*/
-		if(nineRadioButton->isChecked()){
-			version = "nine";
+		if(fifteenRadioButton->isChecked()){
+			version = "fifteen";
 		}
-		if(tenRadioButton->isChecked()){
-			version = "ten";
-		}
-		if(elevenRadioButton->isChecked()){
-			version = "eleven";
-		}
-		if(twelveRadioButton->isChecked()){
-			version = "twelve";
+		if(sixteenRadioButton->isChecked()){
+			version = "sixteen";
 		}
 	}
 	if(jpRadioButton->isChecked()){
 		Q3Url url_for_fedora("ftp://ftp.riken.jp");
 		url_for_fedora.setPort(21);
 		mirror = 2;
-		/*
-		if(sevenRadioButton->isChecked()){
-			version = "seven";
+		if(thirteenRadioButton->isChecked()){
+			version = "thirteen";
 		}
-		if(eightRadioButton->isChecked()){
-			version = "eight";
+		if(fourteenRadioButton->isChecked()){
+			version = "fourteen";
 		}
-		*/
-		if(nineRadioButton->isChecked()){
-			version = "nine";
+		if(fifteenRadioButton->isChecked()){
+			version = "fifteen";
 		}
-		if(tenRadioButton->isChecked()){
-			version = "ten";
+		if(sixteenRadioButton->isChecked()){
+			version = "sixteen";
 		}
-		if(elevenRadioButton->isChecked()){
-			version = "eleven";
+	}
+	if(deRadioButton->isChecked()){
+		Q3Url url_for_fedora("ftp://ftp.uni-kl.de");
+		url_for_fedora.setPort(21);
+		mirror = 2;
+		if(thirteenRadioButton->isChecked()){
+			version = "thirteen";
 		}
-		if(twelveRadioButton->isChecked()){
-			version = "twelve";
+		if(fourteenRadioButton->isChecked()){
+			version = "fourteen";
+		}
+		if(fifteenRadioButton->isChecked()){
+			version = "fifteen";
+		}
+		if(sixteenRadioButton->isChecked()){
+			version = "sixteen";
+		}
+	}
+	if(frRadioButton->isChecked()){
+		Q3Url url_for_fedora("ftp://ftp.lip6.fr");
+		url_for_fedora.setPort(21);
+		mirror = 2;
+		if(thirteenRadioButton->isChecked()){
+			version = "thirteen";
+		}
+		if(fourteenRadioButton->isChecked()){
+			version = "fourteen";
+		}
+		if(fifteenRadioButton->isChecked()){
+			version = "fifteen";
+		}
+		if(sixteenRadioButton->isChecked()){
+			version = "sixteen";
+		}
+	}
+	if(auRadioButton->isChecked()){
+		Q3Url url_for_fedora("ftp://mirror.aarnet.edu.au");
+		url_for_fedora.setPort(21);
+		mirror = 2;
+		if(thirteenRadioButton->isChecked()){
+			version = "thirteen";
+		}
+		if(fourteenRadioButton->isChecked()){
+			version = "fourteen";
+		}
+		if(fifteenRadioButton->isChecked()){
+			version = "fifteen";
+		}
+		if(sixteenRadioButton->isChecked()){
+			version = "sixteen";
 		}
 	}
 	downloader_process(url_for_fedora,version);
