@@ -1,7 +1,7 @@
 /*
  * segatex SELinux tool.
  *
- * Copyright (C) 2007-2010 Shintaro Fujiwara 
+ * Copyright (C) 2007-2012 Shintaro Fujiwara 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -67,12 +67,13 @@ private:
 
         QRadioButton *usRadioButton;
         QRadioButton *jpRadioButton;
-        //QRadioButton *sevenRadioButton;
-        //QRadioButton *eightRadioButton;
-        QRadioButton *nineRadioButton;
-        QRadioButton *tenRadioButton;
-        QRadioButton *elevenRadioButton;
-        QRadioButton *twelveRadioButton;
+        QRadioButton *deRadioButton;
+        QRadioButton *frRadioButton;
+        QRadioButton *auRadioButton;
+        QRadioButton *thirteenRadioButton;
+        QRadioButton *fourteenRadioButton;
+        QRadioButton *fifteenRadioButton;
+        QRadioButton *sixteenRadioButton;
 
         QString semanageEditLineEdit_str_add_restorecon;
 	QPushButton *downloadButton;
@@ -83,9 +84,7 @@ private:
 	Q3HBoxLayout *firstLayout;
 	Q3VBoxLayout *secondLayout;
 	Q3VBoxLayout *thirdLayout;
-	//QVBoxLayout *leftLayout;
 	Q3HBoxLayout *rightLayout;
-	//QVBoxLayout *underLayout;
 	Q3HBoxLayout *footLayout;
 
         QDir dir;
