@@ -119,7 +119,7 @@ void Restorecon::add_button_clicked_process(QString semanageEditLineEdit_str)
 	//cout << "semanageEditLineEdit_str_add_restorecon:" << semanageEditLineEdit_str_add_restorecon << endl;
 	//
         #define PWD_BUF 8600
-        const char* restorecon_file="/root/segatex/semanage/restoreconed";
+        const char* restorecon_file="/usr/share/segatex/semanage/restoreconed";
         ofstream os_add_restorecon;
         os_add_restorecon.open(restorecon_file);
         if(os_add_restorecon){
@@ -161,7 +161,7 @@ void Restorecon::add_button_clicked_process(QString semanageEditLineEdit_str)
 void Restorecon::restorecon_base_fcontext()
 {
         #define PWD_BUF 8600
-        const char* semanage_fcontext_list_file="/root/segatex/semanage/1_fcontext";
+        const char* semanage_fcontext_list_file="/usr/share/segatex/semanage/1_fcontext";
         ofstream os;
         os.open(semanage_fcontext_list_file);
         if(os){
@@ -193,7 +193,7 @@ void Restorecon::readFromOutputFile()
 {
 	/////////////////////////////////////////////////////////////
 	//path = "./";
-	path = "/root/segatex/semanage";
+	path = "/usr/share/segatex/semanage";
 	/////////////////////////////////////////////////////////////
 	forward_slash = "/";
 	dir.setPath(path);
