@@ -1,7 +1,7 @@
 /*
  * segatex SELinux tool.
  *
- * Copyright (C) 2007 Shintaro Fujiwara 
+ * Copyright (C) 2007-2009 Shintaro Fujiwara 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -152,9 +152,9 @@ void SemoduleCoreProcess::remove_button_clicked()
 /* this slot does just make .pp file */
 void SemoduleCoreProcess::make_button_clicked_process(QString moduleEditLineEdit_str)
 {
-	moduleEditLineEdit_str_pp = "cd /root/segatex;make -f /usr/share/selinux/devel/Makefile " + moduleEditLineEdit_str + ".pp";
+	moduleEditLineEdit_str_pp = "cd /usr/share/segatex;rm /usr/share/segatex/make_module_file;make -f /usr/share/selinux/devel/Makefile " + moduleEditLineEdit_str + ".pp";
         #define PWD_BUF 8600
-        const char* make_module_file="/root/segatex/make_module_file";
+        const char* make_module_file="/usr/share/segatex/make_module_file";
         ofstream os;
         os.open(make_module_file);
         if(os){
@@ -186,9 +186,9 @@ void SemoduleCoreProcess::make_button_clicked_process(QString moduleEditLineEdit
 /* this slot does just semanage -i .pp file */
 void SemoduleCoreProcess::install_button_clicked_process(QString moduleEditLineEdit_str)
 {
-	moduleEditLineEdit_str_pp = "cd /root/segatex;semodule -i " + moduleEditLineEdit_str + ".pp";
+	moduleEditLineEdit_str_pp = "rm /usr/share/segatex/install_module_file;cd /usr/share/segatex;semodule -i " + moduleEditLineEdit_str + ".pp";
         #define PWD_BUF 8600
-        const char* install_module_file="/root/segatex/install_module_file";
+        const char* install_module_file="/usr/share/segatex/install_module_file";
         ofstream os;
         os.open(install_module_file);
         if(os){
@@ -221,9 +221,9 @@ void SemoduleCoreProcess::install_button_clicked_process(QString moduleEditLineE
 /* this slot does just semodule -u .pp file */
 void SemoduleCoreProcess::update_button_clicked_process(QString moduleEditLineEdit_str)
 {
-	moduleEditLineEdit_str_pp = "cd /root/segatex;semodule -u " + moduleEditLineEdit_str + ".pp";
+	moduleEditLineEdit_str_pp = "cd /usr/share/segatex;rm /usr/share/segatex/update_module_file;semodule -u " + moduleEditLineEdit_str + ".pp";
         #define PWD_BUF 8600
-        const char* update_module_file="/root/segatex/update_module_file";
+        const char* update_module_file="/usr/share/segatex/update_module_file";
         ofstream os;
         os.open(update_module_file);
         if(os){
@@ -257,7 +257,7 @@ void SemoduleCoreProcess::remove_button_clicked_process(QString moduleEditLineEd
 {
 	moduleEditLineEdit_str_pp = "semodule -r " + moduleEditLineEdit_str;
         #define PWD_BUF 8600
-        const char* remove_module_file="/root/segatex/remove_module_file";
+        const char* remove_module_file="/usr/share/segatex/remove_module_file";
         ofstream os;
         os.open(remove_module_file);
         if(os){
@@ -318,7 +318,7 @@ void SemoduleCoreProcess::processExited()
 void SemoduleCoreProcess::semodule_core_base_process()
 {
         #define PWD_BUF 8600
-        const char* module_list_file="/root/segatex/module_list";
+        const char* module_list_file="/usr/share/segatex/module_list_2";
         ofstream os;
         os.open(module_list_file);
         if(os){
@@ -341,8 +341,30 @@ void SemoduleCoreProcess::semodule_core_base_process()
                 //os.close();
         }
 	os.close();
+
+        const char* module_list_file2="/usr/share/segatex/module_list_1";
+        ofstream os2;
+        os2.open(module_list_file2);
+        if(os2){
+                FILE *read_fp;
+                #define SIZE_TMP 8600
+                char buffer[SIZE_TMP];
+                int chars_read;
+                memset(buffer, '\0', sizeof(buffer));
+                read_fp = popen("/usr/sbin/semodule -l|grep permissive", "r");
+                if(read_fp != NULL){
+                        chars_read = fread(buffer, sizeof(char), SIZE_TMP, read_fp);
+                        while(chars_read>0){
+                                buffer[chars_read -1] = '\0';
+                                os2 << buffer;
+                                chars_read= fread(buffer, sizeof(char), SIZE_TMP, read_fp);
+                        }
+                        pclose(read_fp);
+                }
+        }
+	os2.close();
 	//outputfile_str_common = module_list_file;
-	outputfile_str_common = "module_list";
+	outputfile_str_common = "module_list*";
 	readFromOutputFile();
 
 //	for(int i=0;i<button_numbers;i++){
@@ -350,38 +372,13 @@ void SemoduleCoreProcess::semodule_core_base_process()
 //	}
 
 }
-/*
-void SemoduleCoreProcess::semodule_core_base_process()
-{
-cout << "process" << endl;
-	outputfile_str = "semodule_l.out";
-	this->setEnabled(false);
-	process = new QProcess(this);
-	process->addArgument("/usr/sbin/semodule");
-	process->addArgument("-l");
-	//process->addArgument("|");
-	//process->addArgument("grep");
-	//process->addArgument("[a-zA-Z0-9]");
-	//process->addArgument(">");
-	outputfile_str_common = outputfile_str;
-	//process->addArgument(outputfile_str);
-	outputfile_str_common = outputfile_str;
-	//process->addArgument(outputfile_str);
-	connect(process, SIGNAL(readyReadStdout()),this,SLOT(readFromStdout()));
-	connect(process, SIGNAL(processExited()),this,SLOT(processExited()));
-	process->start();
-
-	//read from .out file
-	readFromOutputFile();
-}
-*/
 
 //this slot should be called from above slot
 void SemoduleCoreProcess::readFromOutputFile()
 {
 	/////////////////////////////////////////////////////////////
 	//path = "./";
-	path = "/root/segatex";
+	path = "/usr/share/segatex";
 	/////////////////////////////////////////////////////////////
 	forward_slash = "/";
 	dir.setPath(path);
@@ -392,46 +389,44 @@ void SemoduleCoreProcess::readFromOutputFile()
 	files = dir.entryList(outputfile_str_common);
 	/////////////////////////////////////////////////////////////
 	it_d = files.begin();
-		while(it_d != files.end()){
-			name = *it_d;
-			file_interface_name = dir_name + forward_slash + name;
-			QFile file( file_interface_name );
-			if ( file.open( QIODevice::ReadOnly ) ) {
-				Q3TextStream stream( &file );
-				////////////////////////////////////////////
-				//agroup = new QButtonGroup( this );
-				//button_numbers = 1;
-				textEdit1->clear();
-				while ( !stream.atEnd() ) {
-					line_analized = stream.readLine(); // line of text excluding '\n'
-					//buttons.push_back(line_analized);
-					textEdit1->append(line_analized);
-					//radiobutton_obj = line_analized + "RadioButton";
-					//radiobutton_obj = line_analized;
-
-					//radiobutton_objButton = new QRadioButton(tr(radiobutton_obj), agroup);
-					//headLayout->addWidget(radiobutton_objButton);
-
-					//radiobutton_obj = line_analized.section( ' ', 0, 0 );
-					//int i = line_analized.find( QRegExp("^[ \t\n\r\f]+"), 0 );
-					//int i = line_analized.find( QRegExp("[\t]"), 0 );
-					//cout << "i:" << i << endl;
-					//cout << "radiobutton_obj:" << radiobutton_obj << endl;
-					//++button_numbers;
-				}
-				file.close();
-				++it_d;
-			}else{
-				//do nothing
+	int order_x;
+	order_x = 1;
+	textEdit1->clear();
+	while(it_d != files.end()){
+		name = *it_d;
+		file_interface_name = dir_name + forward_slash + name;
+		QFile file( file_interface_name );
+		if ( file.open( QIODevice::ReadOnly ) ) {
+			Q3TextStream stream( &file );
+			////////////////////////////////////////////
+			//agroup = new QButtonGroup( this );
+			//button_numbers = 1;
+			if(order_x == 1)
+				textEdit1->append("##permissive domain list##");
+				textEdit1->append("");
+			if(order_x == 2)
+				textEdit1->append("##semodule list##");
+				textEdit1->append("");
+			//textEdit1->clear();
+			while ( !stream.atEnd() ) {
+				line_analized = stream.readLine(); // line of text excluding '\n'
+				textEdit1->append(line_analized);
 			}
+			textEdit1->setCursorPosition(0,0);
+			file.close();
+			order_x++;
+			++it_d;
+		}else{
+			//do nothing
 		}
+	}
 }
 //this slot should be called from above slot
 void SemoduleCoreProcess::readFromOutputFile2()
 {
 	/////////////////////////////////////////////////////////////
 	//path = "./";
-	path = "/root/segatex";
+	path = "/usr/share/segatex";
 	/////////////////////////////////////////////////////////////
 	forward_slash = "/";
 	dir.setPath(path);
